@@ -9,15 +9,13 @@ import urllib.request
 import click
 
 
-
-# @click.group()
+@click.group()
 def main():
-    # pass
-    print(1)
+    pass
 
-# @click.command()
-# @click.option('-u', '--url', default='https://github.com/2003100127/deepsmirud/releases/download/model/model.zip', help='URL of deepsmirud models')
-# @click.option('-o', '--output_path', default='./model.zip', help='output path of deepsmirud models')
+@click.command()
+@click.option('-u', '--url', default='https://github.com/2003100127/deepsmirud/releases/download/model/model.zip', help='URL of deepsmirud models')
+@click.option('-o', '--output_path', default='./model.zip', help='output path of deepsmirud models')
 def download(url, fpn):
     print('downloading...')
     urllib.request.urlretrieve(
@@ -29,8 +27,4 @@ def download(url, fpn):
 
 #
 # if __name__ == '__main__':
-#     main()
-download(
-    'https://github.com/2003100127/deepsmirud/releases/download/model/model.zip',
-    './asds.zip'
-)
\ No newline at end of file
+#     main()
\ No newline at end of file
